
tmpdir/shared.so:     file format elf32-metag

DYNAMIC RELOCATION RECORDS
OFFSET +TYPE +VALUE
.* R_METAG_GLOB_DAT  _var1
.* R_METAG_JMP_SLOT  app_func2


